@@ -1,7 +1,7 @@
 from functools import partial
 
 from flask import (Blueprint, render_template, get_flashed_messages,
-                   _app_ctx_stack)
+                   _app_ctx_stack, session, request)
 from jinja2 import Markup
 from turbo_flask import Turbo
 
@@ -32,6 +32,9 @@ def render_template_modal(*args, **kwargs):
 
     ctx = _app_ctx_stack.top
     ctx._include = True  # used in extension templates
+
+    session['_cond_flashes'] = True  # used in after_app_request function
+
     modal = kwargs.pop('modal', None)
     replace = kwargs.pop('turbo', True)
     update = False
@@ -64,6 +67,21 @@ def render_template_modal(*args, **kwargs):
     return html
 
 
+def render_template_redirect(*args, **kwargs):
+    '''Reload the page to unload the Turbo library. See template
+    `turbo.html`. Flashes need to be saved so that they are again
+    available on reload.
+    '''
+
+    if '_keep_flashes' in session:
+        del session['_keep_flashes']
+        ctx = _app_ctx_stack.top
+        ctx._include = False
+        session['_flashes'] = get_flashed_messages(with_categories=True)
+
+    return render_template(*args, **kwargs)
+
+
 class Modal:
     def __init__(self, app=None):
 
@@ -88,6 +106,22 @@ class Modal:
         bp = Blueprint('modals', __name__, template_folder='templates',
                        static_folder='static',
                        static_url_path='/modals/static')
+
+        @bp.after_app_request
+        def handle_session_vars(response):
+
+            session.pop('_keep_flashes', None)
+
+            if session.get('_cond_flashes'):
+                session['_cond_flashes'] = False
+            elif session.get('_cond_flashes') is False:
+                if request.method == 'POST':
+                    if response.status_code in range(300, 309):
+                        session['_keep_flashes'] = True
+                del session['_cond_flashes']
+
+            return response
+
         app.register_blueprint(bp)
 
     @staticmethod
@@ -110,9 +144,6 @@ class Modal:
         2. nprogress.html - NProgress js library for progress bar
         3. jstemplate.html - Remove extra modal-backdrop divs and
                              control progress bar.
-        4. bodyattr.html - Add attribute to body element to disable
-                           turbo for pages without modal forms.
-                           (always loaded)
         '''
 
         ctx = _app_ctx_stack.top
@@ -121,7 +152,6 @@ class Modal:
 
         html = (Markup(render('modals/turbo.html') +
                        render('modals/nprogress.html') +
-                       render('modals/jstemplate.html') +
-                       render('modals/bodyattr.html')))
+                       render('modals/jstemplate.html')))
 
         return html
